import { useState } from "react";
import { Send } from "lucide-react";
import { Button } from "@/components/ui/button";
import { Card } from "@/components/ui/card";
import { toast } from "sonner";
import { CheckIcon, ChevronDownIcon } from "@radix-ui/react-icons";
import {
  Select,
  SelectTrigger,
  SelectValue,
  SelectContent,
  SelectViewport,
  SelectItem,
  SelectItemText,
  SelectItemIndicator,
  SelectPortal,
} from "@radix-ui/react-select";
import countriesJson from "@/utils/countries.json";
import serviceJson from "@/utils/services.json";


const countries = Object.entries(countriesJson).map(([code, name]) => ({
  code, // Now it correctly stores the country code
  name,
}));

const services = Object.values(serviceJson).map((name, code) => ({
  code: code,
  name,
}));

export function BuyANumber() {
  const [message, setMessage] = useState("");
  const [phoneNumber, setPhoneNumber] = useState("");
  const [isSending, setIsSending] = useState(false);
  const [selectedCountry, setSelectedCountry] = useState("187");
  const [selectedService, setSelectedService] = useState("fb");
  const [response, setResponse] = useState("");

  const handleSend = async () => {
    if (!selectedCountry || !selectedService) {
      toast.error("Please enter both phone number and message");
      return;
    }
    try {
      const myHeaders = new Headers({
        Origin: "*",
      });

      const requestOptions = {
        method: "POST",
        headers: myHeaders,
        body: JSON.stringify({
          action: "getNumber",
          selectedService,
          selectedCountry
        })
      };
      let apiResponse;

      const apiUrl= "https://ikmbnngahzcellthaysf.supabase.co/functions/v1/call-sms-gateway";

      await fetch(apiUrl, requestOptions)
        .then((response) => response.text())
        .then((result) => (apiResponse = result))
        .catch((error) => console.error(error));
      if (apiResponse.includes("ACCESS_NUMBER")) {
        const parts = apiResponse.split(":");
        const lastString = parts[parts.length - 1];
        setResponse(lastString);
        toast.success(`Number Purchased successfully!` + lastString);
      } else {
        toast.error("Something went wrong");
      }
    } catch (error: any) {
      console.error("Detailed error:", error);
      toast.error(
        `Failed to store message: ${error.message || "Please try again"}`
      );
    } finally {
      setIsSending(false);
    }
  };

  return (
    <div className="relative">
      <Card className="p-6 animate-fadeIn overflow-visible">
        <div className="space-y-4">
          <h2 className="text-2xl font-semibold tracking-tight">
            Buy a Number
          </h2>
          <div className="space-y-4">
            <div className="space-y-2">
              <label
                htmlFor="phone"
                className="text-sm font-medium leading-none peer-disabled:cursor-not-allowed peer-disabled:opacity-70"
              >
                Service
              </label>
              <Select
                onValueChange={setSelectedService}
                value={selectedService}
              >
                <SelectTrigger className="inline-flex items-center justify-between w-full px-4 py-2 text-sm font-medium text-left bg-white border border-gray-300 rounded-md shadow-sm hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                  <SelectValue placeholder="Select a country" />
                  <ChevronDownIcon className="w-5 h-5 ml-2" />
                </SelectTrigger>
                <SelectContent className="z-50 fixed">
                  <SelectViewport className="bg-white">
                    {services.map((service) => (
                      <SelectItem
                        key={service?.name?.code}
                        value={service?.name?.code}
                        className="m-4"
                      >
                        <SelectItemText>{service?.name?.name}</SelectItemText>
                        <SelectItemIndicator>
                          <CheckIcon />
                        </SelectItemIndicator>
                      </SelectItem>
                    ))}
                  </SelectViewport>
                </SelectContent>
              </Select>
            </div>
            <div className="space-y-2">
              <label
                htmlFor="phone"
                className="text-sm font-medium leading-none peer-disabled:cursor-not-allowed peer-disabled:opacity-70"
              >
                Country
              </label>
              <Select
                onValueChange={setSelectedCountry}
                value={selectedCountry}
              >
                <SelectTrigger className="inline-flex items-center justify-between w-full px-4 py-2 text-sm font-medium text-left bg-white border border-gray-300 rounded-md shadow-sm hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                  <SelectValue placeholder="Select a country" />
                  <ChevronDownIcon className="w-5 h-5 ml-2" />
                </SelectTrigger>
                <SelectPortal>
                  <SelectContent>
                    <SelectViewport className="bg-white">
                      {countries.map((country) => (
                        <SelectItem
                          className="m-4"
                          key={country.code}
                          value={country.code}
                        >
                          <SelectItemText>{country.name}</SelectItemText>
                          <SelectItemIndicator>
                            <CheckIcon />
                          </SelectItemIndicator>
                        </SelectItem>
                      ))}
                    </SelectViewport>
                  </SelectContent>
                </SelectPortal>
              </Select>
            </div>
            <Button
              onClick={handleSend}
              className="w-full group hover:shadow-md transition-all"
              disabled={isSending}
            >
              <Send className="mr-2 h-4 w-4 group-hover:scale-110 transition-transform" />
              {isSending ? "Buying..." : "Buy A Number"}
            </Button>
          </div>
        </div>
      </Card>
    </div>
  );
}